@@ -26,9 +26,9 @@ void on_message(server* s, websocketpp::connection_hdl hdl, message_ptr msg) {
 
     try {
         s->send(hdl, msg->get_payload(), msg->get_opcode());
-    } catch (const websocketpp::lib::error_code& e) {
+    } catch (websocketpp::exception const & e) {
         s->get_alog().write(websocketpp::log::alevel::app,
-                    "Echo Failed: "+e.message());
+                    std::string("Echo Failed: ")+e.what());
     }
 }
 
@@ -82,12 +82,8 @@ int main() {
             }
             con->eof();
         }
-    } catch (const std::exception & e) {
+    } catch (websocketpp::exception const & e) {
         std::cout << e.what() << std::endl;
-    } catch (websocketpp::lib::error_code e) {
-        std::cout << e.message() << std::endl;
-    } catch (...) {
-        std::cout << "other exception" << std::endl;
     }
     log.close();
 }
